* PROJECT:
* Jan Eeckhout, Roberto Pinheiro, Kurt Schmidheiny
* "Spatial Sorting"
* Forthcoming in the Journal of Political Economy
*
* FILE: 
* section7.do
*
* DESCRIPTION:
* calculate figures 11, 12, 13 and table 1 in section 7
*
* VERSION: 
* Jan-13-2014

clear all
set matsize 1000

* ------------------------------
* Figure 11 and Table 1
* ------------------------------

* open skill data from CPS
use finaldata/skillcps.dta, clear

* sample,  keep only observations
* - identified CBSA 
* - with assigned CBSA housing price
* - cbsa with population > 100000
keep if ~missing(cbsa) & ~missing(rentindexcbsa) & (pop2009>=100000 & ~missing(pop2009))

* define city groups
generate group = .
replace group = 1 if pop2009<=1000000 & pop2009>100000 & ~missing(pop2009)
replace group = 2 if pop2009>2500000 & ~missing(pop2009)
label define group 1 "pop < 1m" 2 "pop > 2.5m"
generate group1 = (group==1) if ~missing(group)
generate group2 = (group==2) if ~missing(group)

* historgram does not take analytical weight, use frequency weights instead
generate double earnwt10000 = round(earnwt*10000,1)

* ------------------------------
*  Table 1
* ------------------------------

* redefine city size group
* 0 = large
* 1 = small
* resulting counterfactual of newgroup: 
* conditional distribution of large cities (group==0) and composition of xvars of small cities (group==1)
generate newgroup = 2-group 

* sample size in footer
sum lutility1 if group==1
codebook cbsa if group==1
sum lutility1 if group==2
codebook cbsa if group==2

* ------------------------------------------------------------
* Table 1, Firpo, Fortin, Lemieux, 2009
* ------------------------------------------------------------

* save results in log
capture log using results/table1_ffl, text replace

* install rifreg from http://faculty.arts.ubc.ca/nfortin/datahead.html

* install oaxaca from http://www.stata-journal.com/software/sj8-4
* net install st0151.pkg

*define the program for bootstraping
program drop _all
program define ffl, eclass

    version 12.0
     
	local xfvar = "grade92 docc00 dind02 myrace sex foreign"
	local agevar = "age age2"
	
	local xfvari = ""
	foreach var of varlist `xfvar' {
		local xfvari = "`xfvari' i.`var'"
	}
	disp "`xfvari'"

	xi `xfvari'

	generate mysample = 0

	* decompose quantiles
	forvalues qt = 10(80)90 {

		gen rif_`qt'=.
		rifreg lutility1 _I* `agevar' if newgroup==0 [aw=earnwt], q(`qt') w(0) re(rif_`qt'_1)
		replace rif_`qt'=rif_`qt'_1 if newgroup==0
		rifreg lutility1  _I* `agevar' if newgroup==1 [aw =earnwt], q(`qt') w(0) re(rif_`qt'_2)
		replace rif_`qt'=rif_`qt'_2 if newgroup==1
		oaxaca rif_`qt'  _I* `agevar', by(newgroup) weight(1) detail //notf
		replace mysample = 1 if e(sample)
		
		local names = ""

		matrix b`qt' = [Differential]_b[Prediction_1]
		local names = "`names' q`qt'_1"
		matrix b`qt' = b`qt'\[Differential]_b[Prediction_2]
		local names = "`names' q`qt'_2"
		matrix b`qt' = b`qt'\[Differential]_b[Difference]
		local names = "`names' d`qt'"	

		* sum up coefficients of groups of variables
		foreach vargroup of varlist `xfvar' {
			scalar sum = 0
			foreach var of varlist _I`vargroup'* {
				scalar sum = sum+[Explained]_b[`var']
			}
			matrix b`qt' = b`qt'\sum
			local names = "`names' be`qt'_`vargroup'"
			*return scalar be`qt'_`vargroup' = `be`qt'_`vargroup''
		}
		scalar sum = 0
		foreach var of varlist `agevar' {
			scalar sum = sum + [Explained]_b[`var']
			*return scalar be`qt'_age = [Explained]_b[`var']
		}
		matrix b`qt' = b`qt'\sum
		local names = "`names' be`qt'_age"
		
		matrix b`qt' = b`qt'\[Explained]_b[Total]
		local names = "`names' be`qt'_total"
		matrix b`qt' = b`qt'\[Unexplained]_b[_cons]
		local names = "`names' bu`qt'_cons"
		matrix b`qt' = b`qt'\[Unexplained]_b[Total]
		local names = "`names' bu`qt'_total"	

		matrix rownames b`qt' = `names'
		matrix colnames b`qt' = "rif_`qt'"
		
	}
	
	*matrix `bb' = `b10'
	matrix b = (b10\b90)'
	ereturn post b, esample(mysample)
   	ereturn local cmd="bootstrap"
		
	drop rif_*
	
end


* point estimates: fast
ffl
matrix list e(b)

* bootstrap standard errors: slow
* uncomment following line to run:
* bootstrap, reps(100): ffl

* note: small deviations of the standard errors from the ones in the published 
* table are in the bootstrap's nature

* close log
log close

* ------------------------------------------------------------
* Table 1, Victor Chernozhukov, Ivan Fernandez-Val and Blaise Melly (forthcoming)
* ------------------------------------------------------------

* save results in log
capture log using results/table1_cfm, text replace

* net install counterfactual, from("http://www.econ.brown.edu/fac/Blaise_Melly/")
* ssc install moremata

* point estimates: slow
xi: cdeco lutility1 i.grade92 i.docc00 i.dind02 i.myrace i.sex i.foreign age age2 [aw=earnwt] , group(newgroup) noboot 

* bootstrap standard errors: very very slow
* uncomment following line to run:
* xi: cdeco lutility1 i.grade92 i.docc00 i.dind02 i.myrace i.sex i.foreign age age2 [aw=earnwt] , group(newgroup) reps(100) saving(temp/cdeco_bs, replace)

* note: small deviations of the standard errors from the ones in the published 
* table are in the bootstrap's nature

* close log
log close

* ------------------------------
* Figure 11 top left
* ------------------------------

* histogram by city size group
#delimit ;
twoway 
	hist gradecat if group==1 [fw=earnwt10000], lpattern(solid) width(1) start(0.3) fcolor(gs10) gap(60) lcolor(black) legend(label(1 "population < 1m"))
	||
	hist gradecat if group==2 [fw=earnwt10000], lpattern(solid) width(1) start(0.7) fcolor(none) gap(60) lcolor(black) legend(label(2 "> 2.5m"))
	, xtitle("") ytitle("density") 
	ylabel(0(.1).5)
	xlabel(
		1 `" "No high"   "school" "'
		2 `" "High school"   "diploma" "'
		3 `" "Some"   "College" "'
		4 `" "Bachelor's"   "and more" "'
		5 `" "Master's"   "and more" "'
		, angle(horizontal)
	)
	scheme(s1mono) legend(region(lstyle(none)))
	xsize(5.50) ysize(4.28) scale(1) 
	note(
	" " 
	" " 
	);
#delimit cr

* save graph
graph export "results/figure_11_top_left.pdf", replace
graph export "results/figure_11_top_left.eps", replace

* ------------------------------
* Figure 11 middle left
* ------------------------------

* histogram by city size group
#delimit ;
twoway 
	hist occcat if group==1 [fw=earnwt10000], lpattern(solid) width(1) start(0.3) fcolor(gs10) gap(60) lcolor(black) legend(label(1 "population < 1m"))
	||
	hist occcat if group==2 [fw=earnwt10000], lpattern(solid) width(1) start(0.7) fcolor(none) gap(60) lcolor(black) legend(label(2 "> 2.5m"))
	, xtitle("occupations ranked by median country-wide wage") ytitle("density") 
	ylabel(0(.1).5)
	xlabel(
		1 "low"
		3 "middle" 
		5 "high"
		, angle(horizontal) 
	)
	scheme(s1mono) legend(region(lstyle(none)))
	xsize(5.50) ysize(4.28) scale(1) 
	note(
	" " 
	" " 
	);
#delimit cr

* save graph
graph export "results/figure_11_middle_left.pdf", replace
graph export "results/figure_11_middle_left.eps", replace

* ------------------------------
* Figure 11 bottom left
* ------------------------------

* histogram by city size group
#delimit ;
twoway 
	hist indcat if group==1 [fw=earnwt10000], lpattern(solid) width(1) start(0.3) fcolor(gs10) gap(60) lcolor(black) legend(label(1 "population < 1m"))
	||
	hist indcat if group==2 [fw=earnwt10000], lpattern(solid) width(1) start(0.7) fcolor(none) gap(60) lcolor(black) legend(label(2 "> 2.5m"))
	, xtitle("industries ranked by median country-wide wage") ytitle("density") 
	xlabel(
		1 "low"
		3 "middle" 
		5 "high"
		, angle(horizontal) 
	)
	scheme(s1mono) legend(region(lstyle(none)))
	xsize(5.50) ysize(4.28) scale(1) 
	note(
	" " 
	" " 
	);
#delimit cr

* save graph
graph export "results/figure_11_bottom_left.pdf", replace
graph export "results/figure_11_bottom_left.eps", replace

* ------------------------------
* Figure 11 right
* ------------------------------

* generate residual skills
foreach condvar of varlist grade92 occ00 ind02 {

	* censored regression of utility on grade/occupation/industry dummies
	* note: use cnreg because "tobit" does not allow for variable truncation point
	xi: cnreg lutility1 i.`condvar' [aw=earnwt], censored(utility1top)
	
	* residual log utility
	predict lutility1`condvar', xb	
	generate lresid2utility1`condvar' = lutility1-lutility1`condvar'					
	label variable lresid2utility1`condvar' "Residual Skill(utility1), not predicted by `condvar'"
	
}

* ------------------------------
* Figure 11 top right
* ------------------------------

* calculate and test selective quantiles of log wage, weighted
foreach quant in 0.1 0.9 {
	local quantpct = 100*`quant'
	quietly qreg lresid2utility1grade92 if group==1 [aw=earnwt], q(`quant') 
	local pctile`quantpct'_group1 = string(_b[_cons],"%9.2f")
	disp "centile(`quantpct'), group==1: " _b[_cons]
	quietly qreg lresid2utility1grade92 if group==2 [aw=earnwt], q(`quant') 
	local pctile`quantpct'_group2 = string(_b[_cons],"%9.2f")
	disp "centile(`quantpct'), group==2: " _b[_cons]
	qreg lresid2utility1grade92 group2 [aw=earnwt], q(`quant')
	local pctile`quantpct'_diff = string(_b[group2],"%9.3f") 
	local pctile`quantpct'_se = string(_se[group2],"%9.3f")
	local pctile`quantpct'_t = string(_b[group2]/_se[group2],"%9.1f")
	local pctile`quantpct'_p = string(ttail(e(df_r), abs(_b[group2]/_se[group2])),"%9.1f")
	if ttail(e(df_r), abs(_b[group2]/_se[group2])) <= 0.01 {
		local pctile`quantpct'_star = "***"
	}
	else if ttail(e(df_r), abs(_b[group2]/_se[group2])) <= 0.05 {
		local pctile`quantpct'_star = "**"
	}
	else if ttail(e(df_r), abs(_b[group2]/_se[group2])) <= 0.1 {
		local pctile`quantpct'_star = "*"
	}
	else {
		local pctile`quantpct'_star = ""
	}
}

* support of kernel density
sum lresid2utility1grade92 if group==1 | group==2
local depvarmaxsmpl = r(max)
local depvarminsmpl = r(min)
local gap = (`depvarminsmpl'-`depvarmaxsmpl')/99
egen x = fill(`depvarminsmpl'[`gap']`depvarmaxsmpl')
replace x =. if _n>100

* kernel density
#delimit ;
kdensity lresid2utility1grade92 if group==1 [aw=earnwt], 
    bwidth(0.1) generate(x1 y1) at(x) nograph;
kdensity lresid2utility1grade92 if group==2 [aw=earnwt], 
    bwidth(0.1) generate(x2 y2) at(x) nograph;
twoway 
    line y1 x1, xlabel(-2(1)2) lpattern(dash) lcolor(black) legend(label(1 "population < 1m")) 
    ||
    line y2 x2, xlabel(-2(1)2) lpattern(solid) lcolor(black) legend(label(2 "> 2.5m"))
	, xtitle("residual skills, controlled for 16 education levels") ytitle("pdf") 
	scheme(s1color) legend(region(lstyle(none)))
	xsize(5.50) ysize(4.28) scale(1)
	note(
	"10th percentile: pop < 1m = `pctile10_group1', pop > 2.5m = `pctile10_group2', diff = `pctile10_diff'`pctile10_star' (`pctile10_se')" 
	"90th percentile: pop < 1m = `pctile90_group1', pop > 2.5m = `pctile90_group2', diff = `pctile90_diff'`pctile90_star' (`pctile90_se')"
	);
#delimit cr
drop x1 x2 y1 y2 x

* save graph
graph export "results/figure_11_top_right.pdf", replace
graph export "results/figure_11_top_right.eps", replace

* ------------------------------
* Figure 11 middle right
* ------------------------------

* calculate and test selective quantiles of log wage, weighted
foreach quant in 0.1 0.9 {
	local quantpct = 100*`quant'
	quietly qreg lresid2utility1occ00 if group==1 [aw=earnwt], q(`quant') 
	local pctile`quantpct'_group1 = string(_b[_cons],"%9.2f")
	disp "centile(`quantpct'), group==1: " _b[_cons]
	quietly qreg lresid2utility1occ00 if group==2 [aw=earnwt], q(`quant') 
	local pctile`quantpct'_group2 = string(_b[_cons],"%9.2f")
	disp "centile(`quantpct'), group==2: " _b[_cons]
	qreg lresid2utility1occ00 group2 [aw=earnwt], q(`quant')
	local pctile`quantpct'_diff = string(_b[group2],"%9.3f") 
	local pctile`quantpct'_se = string(_se[group2],"%9.3f")
	local pctile`quantpct'_t = string(_b[group2]/_se[group2],"%9.1f")
	local pctile`quantpct'_p = string(ttail(e(df_r), abs(_b[group2]/_se[group2])),"%9.1f")
	if ttail(e(df_r), abs(_b[group2]/_se[group2])) <= 0.01 {
		local pctile`quantpct'_star = "***"
	}
	else if ttail(e(df_r), abs(_b[group2]/_se[group2])) <= 0.05 {
		local pctile`quantpct'_star = "**"
	}
	else if ttail(e(df_r), abs(_b[group2]/_se[group2])) <= 0.1 {
		local pctile`quantpct'_star = "*"
	}
	else {
		local pctile`quantpct'_star = ""
	}
}

* support of kernel density
sum lresid2utility1occ00 if group==1 | group==2
local depvarmaxsmpl = r(max)
local depvarminsmpl = r(min)
local gap = (`depvarminsmpl'-`depvarmaxsmpl')/99
egen x = fill(`depvarminsmpl'[`gap']`depvarmaxsmpl')
replace x =. if _n>100

* kernel density
#delimit ;
kdensity lresid2utility1occ00 if group==1 [aw=earnwt], 
    bwidth(0.1) generate(x1 y1) at(x) nograph;
kdensity lresid2utility1occ00 if group==2 [aw=earnwt], 
    bwidth(0.1) generate(x2 y2) at(x) nograph;
twoway 
    line y1 x1, xlabel(-2(1)2) lpattern(dash) lcolor(black) legend(label(1 "population < 1m")) 
    ||
    line y2 x2, xlabel(-2(1)2) lpattern(solid) lcolor(black) legend(label(2 "> 2.5m"))
	, xtitle("residual skills, controlled for 498 occupations") ytitle("pdf") 
	scheme(s1color) legend(region(lstyle(none)))
	xsize(5.50) ysize(4.28) scale(1) 
	note(
	"10th percentile: pop < 1m = `pctile10_group1', pop > 2.5m = `pctile10_group2', diff = `pctile10_diff'`pctile10_star' (`pctile10_se')" 
	"90th percentile: pop < 1m = `pctile90_group1', pop > 2.5m = `pctile90_group2', diff = `pctile90_diff'`pctile90_star' (`pctile90_se')"
);
#delimit cr
drop x1 x2 y1 y2 x

* save graph
graph export "results/figure_11_middle_right.pdf", replace
graph export "results/figure_11_middle_right.eps", replace

* ------------------------------
* Figure 11 bottom right
* ------------------------------

* calculate and test selective quantiles of log wage, weighted
foreach quant in 0.1 0.9 {
	local quantpct = 100*`quant'
	quietly qreg lresid2utility1ind02 if group==1 [aw=earnwt], q(`quant') 
	local pctile`quantpct'_group1 = string(_b[_cons],"%9.2f")
	disp "centile(`quantpct'), group==1: " _b[_cons]
	quietly qreg lresid2utility1ind02 if group==2 [aw=earnwt], q(`quant') 
	local pctile`quantpct'_group2 = string(_b[_cons],"%9.2f")
	disp "centile(`quantpct'), group==2: " _b[_cons]
	qreg lresid2utility1ind02 group2 [aw=earnwt], q(`quant')
	local pctile`quantpct'_diff = string(_b[group2],"%9.3f") 
	local pctile`quantpct'_se = string(_se[group2],"%9.3f")
	local pctile`quantpct'_t = string(_b[group2]/_se[group2],"%9.1f")
	local pctile`quantpct'_p = string(ttail(e(df_r), abs(_b[group2]/_se[group2])),"%9.1f")
	if ttail(e(df_r), abs(_b[group2]/_se[group2])) <= 0.01 {
		local pctile`quantpct'_star = "***"
	}
	else if ttail(e(df_r), abs(_b[group2]/_se[group2])) <= 0.05 {
		local pctile`quantpct'_star = "**"
	}
	else if ttail(e(df_r), abs(_b[group2]/_se[group2])) <= 0.1 {
		local pctile`quantpct'_star = "*"
	}
	else {
		local pctile`quantpct'_star = ""
	}
}

* support of kernel density
sum lresid2utility1ind02 if group==1 | group==2
local depvarmaxsmpl = r(max)
local depvarminsmpl = r(min)
local gap = (`depvarminsmpl'-`depvarmaxsmpl')/99
egen x = fill(`depvarminsmpl'[`gap']`depvarmaxsmpl')
replace x =. if _n>100

* kernel density
#delimit ;
kdensity lresid2utility1ind02 if group==1 [aw=earnwt], 
    bwidth(0.1) generate(x1 y1) at(x) nograph;
kdensity lresid2utility1ind02 if group==2 [aw=earnwt], 
    bwidth(0.1) generate(x2 y2) at(x) nograph;
twoway 
    line y1 x1, xlabel(-2(1)2) lpattern(dash) lcolor(black) legend(label(1 "population < 1m")) 
    ||
    line y2 x2, xlabel(-2(1)2) lpattern(solid) lcolor(black) legend(label(2 "> 2.5m"))
	, xtitle("residual skills, controlled for 262 industries") ytitle("pdf") 
	scheme(s1color) legend(region(lstyle(none)))
	xsize(5.50) ysize(4.28) scale(1) 
	note(
	"10th percentile: pop < 1m = `pctile10_group1', pop > 2.5m = `pctile10_group2', diff = `pctile10_diff'`pctile10_star' (`pctile10_se')" 
	"90th percentile: pop < 1m = `pctile90_group1', pop > 2.5m = `pctile90_group2', diff = `pctile90_diff'`pctile90_star' (`pctile90_se')"
);
#delimit cr
drop x1 x2 y1 y2 x

* save graph
graph export "results/figure_11_bottom_right.pdf", replace
graph export "results/figure_11_bottom_right.eps", replace

* ------------------------------
* Figure 12 left
* ------------------------------

* foreign born sample
generate sample = foreign

* calculate and test selective quantiles of log wage, weighted
foreach quant in 0.1 0.9 {
	local quantpct = 100*`quant'
	quietly qreg lutility1 if group==1 & sample [aw=earnwt], q(`quant') 
	local pctile`quantpct'_group1 = string(_b[_cons],"%9.2f")
	disp "centile(`quantpct'), group==1: " _b[_cons]
	quietly qreg lutility1 if group==2 & sample [aw=earnwt], q(`quant') 
	local pctile`quantpct'_group2 = string(_b[_cons],"%9.2f")
	disp "centile(`quantpct'), group==2: " _b[_cons]
	qreg lutility1 group2 if sample [aw=earnwt], q(`quant')
	local pctile`quantpct'_diff = string(_b[group2],"%9.3f") 
	local pctile`quantpct'_se = string(_se[group2],"%9.3f")
	local pctile`quantpct'_t = string(_b[group2]/_se[group2],"%9.1f")
	local pctile`quantpct'_p = string(ttail(e(df_r), abs(_b[group2]/_se[group2])),"%9.1f")
	if ttail(e(df_r), abs(_b[group2]/_se[group2])) <= 0.01 {
		local pctile`quantpct'_star = "***"
	}
	else if ttail(e(df_r), abs(_b[group2]/_se[group2])) <= 0.05 {
		local pctile`quantpct'_star = "**"
	}
	else if ttail(e(df_r), abs(_b[group2]/_se[group2])) <= 0.1 {
		local pctile`quantpct'_star = "*"
	}
	else {
		local pctile`quantpct'_star = ""
	}
}

* support of kernel density
sum lutility1 if (group==1 | group==2) & sample
local depvarmaxsmpl = r(max)
local depvarminsmpl = r(min)
local gap = (`depvarminsmpl'-`depvarmaxsmpl')/99
egen x = fill(`depvarminsmpl'[`gap']`depvarmaxsmpl')
replace x =. if _n>100

* kernel density
#delimit ;
kdensity lutility1 if group==1 & sample [aw=earnwt], 
    bwidth(0.1) generate(x1 y1) at(x) nograph;
kdensity lutility1 if group==2 & sample [aw=earnwt], 
    bwidth(0.1) generate(x2 y2) at(x) nograph;
twoway 
    line y1 x1, xlabel(5(1)7) lpattern(dash) lcolor(black) legend(label(1 "population < 1m")) 
    ||
    line y2 x2, xlabel(5(1)7) lpattern(solid) lcolor(black) legend(label(2 "> 2.5m"))
	, xtitle("skill (log utility), foreign born") ytitle("pdf") 
	scheme(s1color) legend(region(lstyle(none)))
	xsize(5.50) ysize(4.28) scale(1) 
	note(
	"10th percentile: pop < 1m = `pctile10_group1', pop > 2.5m = `pctile10_group2', diff = `pctile10_diff'`pctile10_star' (`pctile10_se')" 
	"90th percentile: pop < 1m = `pctile90_group1', pop > 2.5m = `pctile90_group2', diff = `pctile90_diff'`pctile90_star' (`pctile90_se')"
);
#delimit cr
drop x1 x2 y1 y2 x
drop sample

* save graph
graph export "results/figure_12_left.pdf", replace
graph export "results/figure_12_left.eps", replace

* ------------------------------
* Figure 12 right
* ------------------------------

* native sample
generate sample = ~foreign

* calculate and test selective quantiles of log wage, weighted
foreach quant in 0.1 0.9 {
	local quantpct = 100*`quant'
	quietly qreg lutility1 if group==1 & sample [aw=earnwt], q(`quant') 
	local pctile`quantpct'_group1 = string(_b[_cons],"%9.2f")
	disp "centile(`quantpct'), group==1: " _b[_cons]
	quietly qreg lutility1 if group==2 & sample [aw=earnwt], q(`quant') 
	local pctile`quantpct'_group2 = string(_b[_cons],"%9.2f")
	disp "centile(`quantpct'), group==2: " _b[_cons]
	qreg lutility1 group2 if sample [aw=earnwt], q(`quant')
	local pctile`quantpct'_diff = string(_b[group2],"%9.3f") 
	local pctile`quantpct'_se = string(_se[group2],"%9.3f")
	local pctile`quantpct'_t = string(_b[group2]/_se[group2],"%9.1f")
	local pctile`quantpct'_p = string(ttail(e(df_r), abs(_b[group2]/_se[group2])),"%9.1f")
	if ttail(e(df_r), abs(_b[group2]/_se[group2])) <= 0.01 {
		local pctile`quantpct'_star = "***"
	}
	else if ttail(e(df_r), abs(_b[group2]/_se[group2])) <= 0.05 {
		local pctile`quantpct'_star = "**"
	}
	else if ttail(e(df_r), abs(_b[group2]/_se[group2])) <= 0.1 {
		local pctile`quantpct'_star = "*"
	}
	else {
		local pctile`quantpct'_star = ""
	}
}

* support of kernel density
sum lutility1 if (group==1 | group==2) & sample
local depvarmaxsmpl = r(max)
local depvarminsmpl = r(min)
local gap = (`depvarminsmpl'-`depvarmaxsmpl')/99
egen x = fill(`depvarminsmpl'[`gap']`depvarmaxsmpl')
replace x =. if _n>100

* kernel density
#delimit ;
kdensity lutility1 if group==1 & sample [aw=earnwt], 
    bwidth(0.1) generate(x1 y1) at(x) nograph;
kdensity lutility1 if group==2 & sample [aw=earnwt], 
    bwidth(0.1) generate(x2 y2) at(x) nograph;
twoway 
    line y1 x1, xlabel(5(1)7) lpattern(dash) lcolor(black) legend(label(1 "population < 1m")) 
    ||
    line y2 x2, xlabel(5(1)7) lpattern(solid) lcolor(black) legend(label(2 "> 2.5m"))
	, xtitle("skill (log utility), natives") ytitle("pdf") 
	scheme(s1color) legend(region(lstyle(none)))
	xsize(5.50) ysize(4.28) scale(1) 
	note(
	"10th percentile: pop < 1m = `pctile10_group1', pop > 2.5m = `pctile10_group2', diff = `pctile10_diff'`pctile10_star' (`pctile10_se')" 
	"90th percentile: pop < 1m = `pctile90_group1', pop > 2.5m = `pctile90_group2', diff = `pctile90_diff'`pctile90_star' (`pctile90_se')"
);
#delimit cr
drop x1 x2 y1 y2 x
drop sample

* save graph
graph export "results/figure_12_right.pdf", replace
graph export "results/figure_12_right.eps", replace

* ------------------------------
* Figure 13 top left
* ------------------------------

* foreign born sample
generate sample = (age>=20 & age<30)

* calculate and test selective quantiles of log wage, weighted
foreach quant in 0.1 0.9 {
	local quantpct = 100*`quant'
	quietly qreg lutility1 if group==1 & sample [aw=earnwt], q(`quant') 
	local pctile`quantpct'_group1 = string(_b[_cons],"%9.2f")
	disp "centile(`quantpct'), group==1: " _b[_cons]
	quietly qreg lutility1 if group==2 & sample [aw=earnwt], q(`quant') 
	local pctile`quantpct'_group2 = string(_b[_cons],"%9.2f")
	disp "centile(`quantpct'), group==2: " _b[_cons]
	qreg lutility1 group2 if sample [aw=earnwt], q(`quant')
	local pctile`quantpct'_diff = string(_b[group2],"%9.3f") 
	local pctile`quantpct'_se = string(_se[group2],"%9.3f")
	local pctile`quantpct'_t = string(_b[group2]/_se[group2],"%9.1f")
	local pctile`quantpct'_p = string(ttail(e(df_r), abs(_b[group2]/_se[group2])),"%9.1f")
	if ttail(e(df_r), abs(_b[group2]/_se[group2])) <= 0.01 {
		local pctile`quantpct'_star = "***"
	}
	else if ttail(e(df_r), abs(_b[group2]/_se[group2])) <= 0.05 {
		local pctile`quantpct'_star = "**"
	}
	else if ttail(e(df_r), abs(_b[group2]/_se[group2])) <= 0.1 {
		local pctile`quantpct'_star = "*"
	}
	else {
		local pctile`quantpct'_star = ""
	}
}

* support of kernel density
sum lutility1 if (group==1 | group==2) & sample
local depvarmaxsmpl = r(max)
local depvarminsmpl = r(min)
local gap = (`depvarminsmpl'-`depvarmaxsmpl')/99
egen x = fill(`depvarminsmpl'[`gap']`depvarmaxsmpl')
replace x =. if _n>100

* kernel density
#delimit ;
kdensity lutility1 if group==1 & sample [aw=earnwt], 
    bwidth(0.1) generate(x1 y1) at(x) nograph;
kdensity lutility1 if group==2 & sample [aw=earnwt], 
    bwidth(0.1) generate(x2 y2) at(x) nograph;
twoway 
    line y1 x1, xlabel(5(1)7) lpattern(dash) lcolor(black) legend(label(1 "population < 1m")) 
    ||
    line y2 x2, xlabel(5(1)7) lpattern(solid) lcolor(black) legend(label(2 "> 2.5m"))
	, xtitle("skill (log utility), 20-29 year old") ytitle("pdf") 
	scheme(s1color) legend(region(lstyle(none)))
	xsize(5.50) ysize(4.28) scale(1) 
	note(
	"10th percentile: pop < 1m = `pctile10_group1', pop > 2.5m = `pctile10_group2', diff = `pctile10_diff'`pctile10_star' (`pctile10_se')" 
	"90th percentile: pop < 1m = `pctile90_group1', pop > 2.5m = `pctile90_group2', diff = `pctile90_diff'`pctile90_star' (`pctile90_se')"
);
#delimit cr
drop x1 x2 y1 y2 x
drop sample

* save graph
graph export "results/figure_13_top_left.pdf", replace
graph export "results/figure_13_top_left.eps", replace

* ------------------------------
* Figure 13 top right
* ------------------------------

* foreign born sample
generate sample = (age>=30 & age<40)

* calculate and test selective quantiles of log wage, weighted
foreach quant in 0.1 0.9 {
	local quantpct = 100*`quant'
	quietly qreg lutility1 if group==1 & sample [aw=earnwt], q(`quant') 
	local pctile`quantpct'_group1 = string(_b[_cons],"%9.2f")
	disp "centile(`quantpct'), group==1: " _b[_cons]
	quietly qreg lutility1 if group==2 & sample [aw=earnwt], q(`quant') 
	local pctile`quantpct'_group2 = string(_b[_cons],"%9.2f")
	disp "centile(`quantpct'), group==2: " _b[_cons]
	qreg lutility1 group2 if sample [aw=earnwt], q(`quant')
	local pctile`quantpct'_diff = string(_b[group2],"%9.3f") 
	local pctile`quantpct'_se = string(_se[group2],"%9.3f")
	local pctile`quantpct'_t = string(_b[group2]/_se[group2],"%9.1f")
	local pctile`quantpct'_p = string(ttail(e(df_r), abs(_b[group2]/_se[group2])),"%9.1f")
	if ttail(e(df_r), abs(_b[group2]/_se[group2])) <= 0.01 {
		local pctile`quantpct'_star = "***"
	}
	else if ttail(e(df_r), abs(_b[group2]/_se[group2])) <= 0.05 {
		local pctile`quantpct'_star = "**"
	}
	else if ttail(e(df_r), abs(_b[group2]/_se[group2])) <= 0.1 {
		local pctile`quantpct'_star = "*"
	}
	else {
		local pctile`quantpct'_star = ""
	}
}

* support of kernel density
sum lutility1 if (group==1 | group==2) & sample
local depvarmaxsmpl = r(max)
local depvarminsmpl = r(min)
local gap = (`depvarminsmpl'-`depvarmaxsmpl')/99
egen x = fill(`depvarminsmpl'[`gap']`depvarmaxsmpl')
replace x =. if _n>100

* kernel density
#delimit ;
kdensity lutility1 if group==1 & sample [aw=earnwt], 
    bwidth(0.1) generate(x1 y1) at(x) nograph;
kdensity lutility1 if group==2 & sample [aw=earnwt], 
    bwidth(0.1) generate(x2 y2) at(x) nograph;
twoway 
    line y1 x1, xlabel(5(1)7) lpattern(dash) lcolor(black) legend(label(1 "population < 1m")) 
    ||
    line y2 x2, xlabel(5(1)7) lpattern(solid) lcolor(black) legend(label(2 "> 2.5m"))
	, xtitle("skill (log utility), 30-39 year old") ytitle("pdf") 
	scheme(s1color) legend(region(lstyle(none)))
	xsize(5.50) ysize(4.28) scale(1) 
	note(
	"10th percentile: pop < 1m = `pctile10_group1', pop > 2.5m = `pctile10_group2', diff = `pctile10_diff'`pctile10_star' (`pctile10_se')" 
	"90th percentile: pop < 1m = `pctile90_group1', pop > 2.5m = `pctile90_group2', diff = `pctile90_diff'`pctile90_star' (`pctile90_se')"
);
#delimit cr
drop x1 x2 y1 y2 x
drop sample

* save graph
graph export "results/figure_13_top_right.pdf", replace
graph export "results/figure_13_top_right.eps", replace

* ------------------------------
* Figure 13 bottom left
* ------------------------------

* foreign born sample
generate sample = (age>=40 & age<50)

* calculate and test selective quantiles of log wage, weighted
foreach quant in 0.1 0.9 {
	local quantpct = 100*`quant'
	quietly qreg lutility1 if group==1 & sample [aw=earnwt], q(`quant') 
	local pctile`quantpct'_group1 = string(_b[_cons],"%9.2f")
	disp "centile(`quantpct'), group==1: " _b[_cons]
	quietly qreg lutility1 if group==2 & sample [aw=earnwt], q(`quant') 
	local pctile`quantpct'_group2 = string(_b[_cons],"%9.2f")
	disp "centile(`quantpct'), group==2: " _b[_cons]
	qreg lutility1 group2 if sample [aw=earnwt], q(`quant')
	local pctile`quantpct'_diff = string(_b[group2],"%9.3f") 
	local pctile`quantpct'_se = string(_se[group2],"%9.3f")
	local pctile`quantpct'_t = string(_b[group2]/_se[group2],"%9.1f")
	local pctile`quantpct'_p = string(ttail(e(df_r), abs(_b[group2]/_se[group2])),"%9.1f")
	if ttail(e(df_r), abs(_b[group2]/_se[group2])) <= 0.01 {
		local pctile`quantpct'_star = "***"
	}
	else if ttail(e(df_r), abs(_b[group2]/_se[group2])) <= 0.05 {
		local pctile`quantpct'_star = "**"
	}
	else if ttail(e(df_r), abs(_b[group2]/_se[group2])) <= 0.1 {
		local pctile`quantpct'_star = "*"
	}
	else {
		local pctile`quantpct'_star = ""
	}
}

* support of kernel density
sum lutility1 if (group==1 | group==2) & sample
local depvarmaxsmpl = r(max)
local depvarminsmpl = r(min)
local gap = (`depvarminsmpl'-`depvarmaxsmpl')/99
egen x = fill(`depvarminsmpl'[`gap']`depvarmaxsmpl')
replace x =. if _n>100

* kernel density
#delimit ;
kdensity lutility1 if group==1 & sample [aw=earnwt], 
    bwidth(0.1) generate(x1 y1) at(x) nograph;
kdensity lutility1 if group==2 & sample [aw=earnwt], 
    bwidth(0.1) generate(x2 y2) at(x) nograph;
twoway 
    line y1 x1, xlabel(5(1)7) lpattern(dash) lcolor(black) legend(label(1 "population < 1m")) 
    ||
    line y2 x2, xlabel(5(1)7) lpattern(solid) lcolor(black) legend(label(2 "> 2.5m"))
	, xtitle("skill (log utility), 40-49 year old") ytitle("pdf") 
	scheme(s1color) legend(region(lstyle(none)))
	xsize(5.50) ysize(4.28) scale(1) 
	note(
	"10th percentile: pop < 1m = `pctile10_group1', pop > 2.5m = `pctile10_group2', diff = `pctile10_diff'`pctile10_star' (`pctile10_se')" 
	"90th percentile: pop < 1m = `pctile90_group1', pop > 2.5m = `pctile90_group2', diff = `pctile90_diff'`pctile90_star' (`pctile90_se')"
);
#delimit cr
drop x1 x2 y1 y2 x
drop sample

* save graph
graph export "results/figure_13_bottom_left.pdf", replace
graph export "results/figure_13_bottom_left.eps", replace

* ------------------------------
* Figure 13 bottom right
* ------------------------------

* foreign born sample
generate sample = (age>=50 & age<60)

* calculate and test selective quantiles of log wage, weighted
foreach quant in 0.1 0.9 {
	local quantpct = 100*`quant'
	quietly qreg lutility1 if group==1 & sample [aw=earnwt], q(`quant') 
	local pctile`quantpct'_group1 = string(_b[_cons],"%9.2f")
	disp "centile(`quantpct'), group==1: " _b[_cons]
	quietly qreg lutility1 if group==2 & sample [aw=earnwt], q(`quant') 
	local pctile`quantpct'_group2 = string(_b[_cons],"%9.2f")
	disp "centile(`quantpct'), group==2: " _b[_cons]
	qreg lutility1 group2 if sample [aw=earnwt], q(`quant')
	local pctile`quantpct'_diff = string(_b[group2],"%9.3f") 
	local pctile`quantpct'_se = string(_se[group2],"%9.3f")
	local pctile`quantpct'_t = string(_b[group2]/_se[group2],"%9.1f")
	local pctile`quantpct'_p = string(ttail(e(df_r), abs(_b[group2]/_se[group2])),"%9.1f")
	if ttail(e(df_r), abs(_b[group2]/_se[group2])) <= 0.01 {
		local pctile`quantpct'_star = "***"
	}
	else if ttail(e(df_r), abs(_b[group2]/_se[group2])) <= 0.05 {
		local pctile`quantpct'_star = "**"
	}
	else if ttail(e(df_r), abs(_b[group2]/_se[group2])) <= 0.1 {
		local pctile`quantpct'_star = "*"
	}
	else {
		local pctile`quantpct'_star = ""
	}
}

* support of kernel density
sum lutility1 if (group==1 | group==2) & sample
local depvarmaxsmpl = r(max)
local depvarminsmpl = r(min)
local gap = (`depvarminsmpl'-`depvarmaxsmpl')/99
egen x = fill(`depvarminsmpl'[`gap']`depvarmaxsmpl')
replace x =. if _n>100

* kernel density
#delimit ;
kdensity lutility1 if group==1 & sample [aw=earnwt], 
    bwidth(0.1) generate(x1 y1) at(x) nograph;
kdensity lutility1 if group==2 & sample [aw=earnwt], 
    bwidth(0.1) generate(x2 y2) at(x) nograph;
twoway 
    line y1 x1, xlabel(5(1)7) lpattern(dash) lcolor(black) legend(label(1 "population < 1m")) 
    ||
    line y2 x2, xlabel(5(1)7) lpattern(solid) lcolor(black) legend(label(2 "> 2.5m"))
	, xtitle("skill (log utility), 50-59 year old") ytitle("pdf") 
	scheme(s1color) legend(region(lstyle(none)))
	xsize(5.50) ysize(4.28) scale(1) 
	note(
	"10th percentile: pop < 1m = `pctile10_group1', pop > 2.5m = `pctile10_group2', diff = `pctile10_diff'`pctile10_star' (`pctile10_se')" 
	"90th percentile: pop < 1m = `pctile90_group1', pop > 2.5m = `pctile90_group2', diff = `pctile90_diff'`pctile90_star' (`pctile90_se')"
);
#delimit cr
drop x1 x2 y1 y2 x
drop sample

* save graph
graph export "results/figure_13_bottom_right.pdf", replace
graph export "results/figure_13_bottom_right.eps", replace
